import { queryGenerator } from './chunk-AQR2IYY6.js';
import { QueryKey } from './chunk-P7PP4SS2.js';
import path from 'node:path';
import { createPlugin, PluginManager, FileManager } from '@kubb/core';
import { camelCase, pascalCase } from '@kubb/core/transformers';
import { pluginOasName, OperationGenerator } from '@kubb/plugin-oas';
import { pluginTsName } from '@kubb/plugin-ts';
import { pluginZodName } from '@kubb/plugin-zod';

var pluginSolidQueryName = "plugin-solid-query";
var pluginSolidQuery = createPlugin((options) => {
  const {
    output = { path: "hooks", barrelType: "named" },
    group,
    exclude = [],
    include,
    override = [],
    parser = "client",
    transformers = {},
    paramsType = "inline",
    pathParamsType = paramsType === "object" ? "object" : options.pathParamsType || "inline",
    queryKey = QueryKey.getTransformer,
    generators = [queryGenerator].filter(Boolean),
    query = {},
    paramsCasing,
    contentType
  } = options;
  return {
    name: pluginSolidQueryName,
    options: {
      output,
      client: {
        importPath: "@kubb/plugin-client/clients/axios",
        dataReturnType: "data",
        pathParamsType,
        ...options.client
      },
      queryKey,
      query: query === false ? false : {
        methods: ["get"],
        importPath: "@tanstack/solid-query",
        ...query
      },
      paramsType,
      pathParamsType,
      parser,
      group,
      paramsCasing
    },
    pre: [pluginOasName, pluginTsName, parser === "zod" ? pluginZodName : void 0].filter(Boolean),
    resolvePath(baseName, pathMode, options2) {
      const root = path.resolve(this.config.root, this.config.output.path);
      const mode = pathMode ?? FileManager.getMode(path.resolve(root, output.path));
      if (mode === "single") {
        return path.resolve(root, output.path);
      }
      if (group && (options2?.group?.path || options2?.group?.tag)) {
        const groupName = group?.name ? group.name : (ctx) => {
          if (group?.type === "path") {
            return `${ctx.group.split("/")[1]}`;
          }
          return `${camelCase(ctx.group)}Controller`;
        };
        return path.resolve(
          root,
          output.path,
          groupName({
            group: group.type === "path" ? options2.group.path : options2.group.tag
          }),
          baseName
        );
      }
      return path.resolve(root, output.path, baseName);
    },
    resolveName(name, type) {
      let resolvedName = camelCase(name);
      if (type === "file" || type === "function") {
        resolvedName = camelCase(name, {
          isFile: type === "file"
        });
      }
      if (type === "type") {
        resolvedName = pascalCase(name);
      }
      if (type) {
        return transformers?.name?.(resolvedName, type) || resolvedName;
      }
      return resolvedName;
    },
    async buildStart() {
      const [swaggerPlugin] = PluginManager.getDependedPlugins(this.plugins, [pluginOasName]);
      const oas = await swaggerPlugin.context.getOas();
      const root = path.resolve(this.config.root, this.config.output.path);
      const mode = FileManager.getMode(path.resolve(root, output.path));
      const baseURL = await swaggerPlugin.context.getBaseURL();
      if (baseURL) {
        this.plugin.options.client.baseURL = baseURL;
      }
      const operationGenerator = new OperationGenerator(this.plugin.options, {
        oas,
        pluginManager: this.pluginManager,
        plugin: this.plugin,
        contentType,
        exclude,
        include,
        override,
        mode
      });
      const files = await operationGenerator.build(...generators);
      await this.addFile(...files);
      const barrelFiles = await this.fileManager.getBarrelFiles({
        type: output.barrelType ?? "named",
        root,
        output,
        files: this.fileManager.files,
        meta: {
          pluginKey: this.plugin.key
        },
        logger: this.logger
      });
      await this.addFile(...barrelFiles);
    }
  };
});

export { pluginSolidQuery, pluginSolidQueryName };
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map